@@ -42,16 +42,13 @@ class ApprcWatcher(CircusPlugin):
                     self.add_envs(name, envs)
 
     def add_envs(self, name, envs):
-        current = self.call("options", name=name)["env"]
+        current = self.call("options", name=name)["options"]["env"]
         path = current.get("PATH")
         if path and "PATH" not in envs:
             envs = copy.deepcopy(envs)
             envs["PATH"] = path
         self.call("set", name=name, options={"env": envs})
 
-    def restart(self, name):
-        pass
-
     def envs(self):
         environs = {}
         with open(self.apprc) as file:
